@@ -1,8 +1,8 @@
 import random
 import pandas as pd
 
-from src.tars.tars import TraderEvaluator
-from src.tars.tars import AbstractStrategy
+from .abstract_strategy import AbstractStrategy
+from ..evaluators import TraderEvaluator
 
 
 class RandomInvestment(AbstractStrategy):
