@@ -1,8 +1,9 @@
 import time
+
 import pandas as pd
 
-from src.tars.tars import TraderEvaluator
-from src.tars.tars import AbstractStrategy
+from .abstract_strategy import AbstractStrategy
+from ..evaluators import TraderEvaluator
 
 
 class SequentialInvestment(AbstractStrategy):
